=======
agrimpy
=======

**agrimpy** utiliza pyproj para hacer algunas opreaciones con coordenadas geodésicas.

Instalación
===========

Ejecutar en la terminal::

    $ sudo pip install agrimpy

Uso
====

Ver archivo ``test.py`` con ejemplos.

To do
=====

- ...
- ayudame con un pull-request en https://github.com/quijot/agrimpy-package

Autor
=====

* Santiago Pestarini <santiagonob@gmail.com>

Licencia
========

**agrimpy** is licensed under the *MIT License*. See the LICENSE file.
